import { Chain } from 'wagmi/chains';
import { InjectedParameters } from 'wagmi/connectors';
import CapsuleWeb, { CapsuleModalProps } from '@usecapsule/react-sdk';
import { Transport } from 'viem';
interface CapsuleConnectorOpts extends Partial<CapsuleModalProps> {
    /**
     * @deprecated Use `chains` in the wagmi config instead.
     */
    chains?: Chain[];
    options: InjectedParameters;
    capsule: CapsuleWeb;
    disableModal?: boolean;
    appName: string;
    idOverride?: string;
    storageOverride?: Pick<Storage, 'setItem' | 'getItem'>;
    iconOverride?: string;
    nameOverride?: string;
    transports?: Record<number, Transport>;
}
export declare const capsuleConnector: ({ capsule, chains: _chains, disableModal, storageOverride, options, iconOverride, nameOverride, idOverride, transports, ...modalProps }: CapsuleConnectorOpts) => import("wagmi").CreateConnectorFn<unknown, {
    type: string;
    name: string;
    icon: string;
    disconnect: () => Promise<void>;
    id: string;
    supportsSimulation?: boolean;
    setup?: () => Promise<void>;
    connect: (parameters?: {
        chainId?: number;
        isReconnecting?: boolean;
    }) => Promise<{
        accounts: readonly `0x${string}`[];
        chainId: number;
    }>;
    getAccounts: () => Promise<readonly `0x${string}`[]>;
    getChainId: () => Promise<number>;
    getProvider: (parameters?: {
        chainId?: number;
    }) => Promise<{
        on: <TEvent extends keyof import("viem").EIP1193EventMap>(event: TEvent, listener: import("viem").EIP1193EventMap[TEvent]) => void;
        removeListener: <TEvent_1 extends keyof import("viem").EIP1193EventMap>(event: TEvent_1, listener: import("viem").EIP1193EventMap[TEvent_1]) => void;
        request: import("viem").EIP1193RequestFn<[{
            Method: "web3_clientVersion";
            Parameters?: undefined;
            ReturnType: string;
        }, {
            Method: "web3_sha3";
            Parameters: [data: `0x${string}`];
            ReturnType: string;
        }, {
            Method: "net_listening";
            Parameters?: undefined;
            ReturnType: boolean;
        }, {
            Method: "net_peerCount";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "net_version";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_blobBaseFee";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_blockNumber";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_call";
            Parameters: [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>] | [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier] | [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier, stateOverrideSet: import("viem").RpcStateOverride];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_chainId";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_coinbase";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_estimateGas";
            Parameters: [transaction: import("viem").RpcTransactionRequest] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag, stateOverride: import("viem").RpcStateOverride];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_feeHistory";
            Parameters: [blockCount: `0x${string}`, newestBlock: `0x${string}` | import("viem").BlockTag, rewardPercentiles: number[]];
            ReturnType: import("viem").RpcFeeHistory;
        }, {
            Method: "eth_gasPrice";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getBalance";
            Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getBlockByHash";
            Parameters: [hash: `0x${string}`, includeTransactionObjects: boolean];
            ReturnType: import("viem").RpcBlock;
        }, {
            Method: "eth_getBlockByNumber";
            Parameters: [block: `0x${string}` | import("viem").BlockTag, includeTransactionObjects: boolean];
            ReturnType: import("viem").RpcBlock;
        }, {
            Method: "eth_getBlockTransactionCountByHash";
            Parameters: [hash: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getBlockTransactionCountByNumber";
            Parameters: [block: `0x${string}` | import("viem").BlockTag];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getCode";
            Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getFilterChanges";
            Parameters: [filterId: `0x${string}`];
            ReturnType: `0x${string}`[] | {
                address: `0x${string}`;
                blockHash: `0x${string}`;
                blockNumber: `0x${string}`;
                data: `0x${string}`;
                logIndex: `0x${string}`;
                transactionHash: `0x${string}`;
                transactionIndex: `0x${string}`;
                removed: boolean;
            }[];
        }, {
            Method: "eth_getFilterLogs";
            Parameters: [filterId: `0x${string}`];
            ReturnType: {
                address: `0x${string}`;
                blockHash: `0x${string}`;
                blockNumber: `0x${string}`;
                data: `0x${string}`;
                logIndex: `0x${string}`;
                transactionHash: `0x${string}`;
                transactionIndex: `0x${string}`;
                removed: boolean;
            }[];
        }, {
            Method: "eth_getLogs";
            Parameters: [{
                address?: `0x${string}` | `0x${string}`[];
                topics?: import("viem").LogTopic[];
            } & ({
                fromBlock?: `0x${string}` | import("viem").BlockTag;
                toBlock?: `0x${string}` | import("viem").BlockTag;
                blockHash?: undefined;
            } | {
                fromBlock?: undefined;
                toBlock?: undefined;
                blockHash?: `0x${string}`;
            })];
            ReturnType: {
                address: `0x${string}`;
                blockHash: `0x${string}`;
                blockNumber: `0x${string}`;
                data: `0x${string}`;
                logIndex: `0x${string}`;
                transactionHash: `0x${string}`;
                transactionIndex: `0x${string}`;
                removed: boolean;
            }[];
        }, {
            Method: "eth_getProof";
            Parameters: [address: `0x${string}`, storageKeys: `0x${string}`[], block: `0x${string}` | import("viem").BlockTag];
            ReturnType: import("viem").RpcProof;
        }, {
            Method: "eth_getStorageAt";
            Parameters: [address: `0x${string}`, index: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getTransactionByBlockHashAndIndex";
            Parameters: [hash: `0x${string}`, index: `0x${string}`];
            ReturnType: import("viem").RpcTransaction;
        }, {
            Method: "eth_getTransactionByBlockNumberAndIndex";
            Parameters: [block: `0x${string}` | import("viem").BlockTag, index: `0x${string}`];
            ReturnType: import("viem").RpcTransaction;
        }, {
            Method: "eth_getTransactionByHash";
            Parameters: [hash: `0x${string}`];
            ReturnType: import("viem").RpcTransaction;
        }, {
            Method: "eth_getTransactionCount";
            Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getTransactionReceipt";
            Parameters: [hash: `0x${string}`];
            ReturnType: import("viem").RpcTransactionReceipt;
        }, {
            Method: "eth_getUncleByBlockHashAndIndex";
            Parameters: [hash: `0x${string}`, index: `0x${string}`];
            ReturnType: import("viem").RpcUncle;
        }, {
            Method: "eth_getUncleByBlockNumberAndIndex";
            Parameters: [block: `0x${string}` | import("viem").BlockTag, index: `0x${string}`];
            ReturnType: import("viem").RpcUncle;
        }, {
            Method: "eth_getUncleCountByBlockHash";
            Parameters: [hash: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_getUncleCountByBlockNumber";
            Parameters: [block: `0x${string}` | import("viem").BlockTag];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_maxPriorityFeePerGas";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_newBlockFilter";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_newFilter";
            Parameters: [filter: {
                fromBlock?: `0x${string}` | import("viem").BlockTag;
                toBlock?: `0x${string}` | import("viem").BlockTag;
                address?: `0x${string}` | `0x${string}`[];
                topics?: import("viem").LogTopic[];
            }];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_newPendingTransactionFilter";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_protocolVersion";
            Parameters?: undefined;
            ReturnType: string;
        }, {
            Method: "eth_sendRawTransaction";
            Parameters: [signedTransaction: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_uninstallFilter";
            Parameters: [filterId: `0x${string}`];
            ReturnType: boolean;
        }, {
            Method: "eth_accounts";
            Parameters?: undefined;
            ReturnType: `0x${string}`[];
        }, {
            Method: "eth_chainId";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_estimateGas";
            Parameters: [transaction: import("viem").RpcTransactionRequest] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag, stateOverride: import("viem").RpcStateOverride];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_requestAccounts";
            Parameters?: undefined;
            ReturnType: `0x${string}`[];
        }, {
            Method: "eth_sendTransaction";
            Parameters: [transaction: import("viem").RpcTransactionRequest];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_sendRawTransaction";
            Parameters: [signedTransaction: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_sign";
            Parameters: [address: `0x${string}`, data: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_signTransaction";
            Parameters: [request: import("viem").RpcTransactionRequest];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_signTypedData_v4";
            Parameters: [address: `0x${string}`, message: string];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_syncing";
            Parameters?: undefined;
            ReturnType: false | import("viem").NetworkSync;
        }, {
            Method: "personal_sign";
            Parameters: [data: `0x${string}`, address: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "wallet_addEthereumChain";
            Parameters: [chain: import("viem").AddEthereumChainParameter];
            ReturnType: null;
        }, {
            Method: "wallet_getCallsStatus";
            Parameters?: [string];
            ReturnType: import("viem").WalletGetCallsStatusReturnType<`0x${string}`, `0x${string}`>;
        }, {
            Method: "wallet_getCapabilities";
            Parameters?: [`0x${string}`];
            ReturnType: {
                [x: `0x${string}`]: import("viem").WalletCapabilities;
            };
        }, {
            Method: "wallet_getPermissions";
            Parameters?: undefined;
            ReturnType: import("viem").WalletPermission[];
        }, {
            Method: "wallet_grantPermissions";
            Parameters?: [import("viem").WalletGrantPermissionsParameters];
            ReturnType: {
                expiry: number;
                factory?: `0x${string}`;
                factoryData?: string;
                grantedPermissions: readonly {
                    data: unknown;
                    policies: readonly {
                        data: unknown;
                        type: string;
                    }[];
                    required?: boolean;
                    type: string;
                }[];
                permissionsContext: string;
                signerData?: {
                    userOpBuilder?: `0x${string}`;
                    submitToAddress?: `0x${string}`;
                };
            };
        }, {
            Method: "wallet_requestPermissions";
            Parameters: [permissions: {
                eth_accounts: Record<string, any>;
            }];
            ReturnType: import("viem").WalletPermission[];
        }, {
            Method: "wallet_revokePermissions";
            Parameters: [permissions: {
                eth_accounts: Record<string, any>;
            }];
            ReturnType: null;
        }, {
            Method: "wallet_sendCalls";
            Parameters?: import("viem").WalletSendCallsParameters<import("viem").WalletCapabilities, `0x${string}`, `0x${string}`>;
            ReturnType: string;
        }, {
            Method: "wallet_showCallsStatus";
            Parameters?: [string];
            ReturnType: void;
        }, {
            Method: "wallet_switchEthereumChain";
            Parameters: [chain: {
                chainId: string;
            }];
            ReturnType: null;
        }, {
            Method: "wallet_watchAsset";
            Parameters: import("viem").WatchAssetParams;
            ReturnType: boolean;
        }, {
            Method: "eth_chainId";
            Parameters?: undefined;
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_estimateUserOperationGas";
            Parameters: [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`] | [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`, stateOverrideSet: import("viem").RpcStateOverride];
            ReturnType: import("viem").RpcEstimateUserOperationGasReturnType;
        }, {
            Method: "eth_getUserOperationByHash";
            Parameters: [hash: `0x${string}`];
            ReturnType: import("viem").RpcGetUserOperationByHashReturnType;
        }, {
            Method: "eth_getUserOperationReceipt";
            Parameters: [hash: `0x${string}`];
            ReturnType: import("viem").RpcUserOperationReceipt;
        }, {
            Method: "eth_sendUserOperation";
            Parameters: [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`];
            ReturnType: `0x${string}`;
        }, {
            Method: "eth_supportedEntryPoints";
            Parameters?: undefined;
            ReturnType: readonly `0x${string}`[];
        }, {
            Method: "pm_getPaymasterStubData";
            Parameters?: [userOperation: import("viem").OneOf<import("wagmi/chains").PartialBy<Pick<{
                callData: `0x${string}`;
                callGasLimit: `0x${string}`;
                initCode?: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                nonce: `0x${string}`;
                paymasterAndData?: `0x${string}`;
                preVerificationGas: `0x${string}`;
                sender: `0x${string}`;
                signature: `0x${string}`;
                verificationGasLimit: `0x${string}`;
            }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "preVerificationGas" | "sender" | "verificationGasLimit" | "initCode">, "maxFeePerGas" | "maxPriorityFeePerGas" | "callGasLimit" | "preVerificationGas" | "verificationGasLimit" | "initCode"> | import("wagmi/chains").PartialBy<Pick<{
                callData: `0x${string}`;
                callGasLimit: `0x${string}`;
                factory?: `0x${string}`;
                factoryData?: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                nonce: `0x${string}`;
                paymaster?: `0x${string}`;
                paymasterData?: `0x${string}`;
                paymasterPostOpGasLimit?: `0x${string}`;
                paymasterVerificationGasLimit?: `0x${string}`;
                preVerificationGas: `0x${string}`;
                sender: `0x${string}`;
                signature: `0x${string}`;
                verificationGasLimit: `0x${string}`;
            }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "sender" | "verificationGasLimit">, "maxFeePerGas" | "maxPriorityFeePerGas" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "verificationGasLimit">>, entrypoint: `0x${string}`, chainId: `0x${string}`, context: unknown];
            ReturnType: import("viem").OneOf<{
                paymasterAndData: `0x${string}`;
            } | {
                paymaster: `0x${string}`;
                paymasterData: `0x${string}`;
                paymasterVerificationGasLimit: `0x${string}`;
                paymasterPostOpGasLimit: `0x${string}`;
            }> & {
                sponsor?: {
                    name: string;
                    icon?: string;
                };
                isFinal?: boolean;
            };
        }, {
            Method: "pm_getPaymasterData";
            Parameters?: [userOperation: Pick<{
                callData: `0x${string}`;
                callGasLimit: `0x${string}`;
                initCode?: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                nonce: `0x${string}`;
                paymasterAndData?: `0x${string}`;
                preVerificationGas: `0x${string}`;
                sender: `0x${string}`;
                signature: `0x${string}`;
                verificationGasLimit: `0x${string}`;
            }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "preVerificationGas" | "sender" | "verificationGasLimit" | "initCode"> | Pick<{
                callData: `0x${string}`;
                callGasLimit: `0x${string}`;
                factory?: `0x${string}`;
                factoryData?: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                nonce: `0x${string}`;
                paymaster?: `0x${string}`;
                paymasterData?: `0x${string}`;
                paymasterPostOpGasLimit?: `0x${string}`;
                paymasterVerificationGasLimit?: `0x${string}`;
                preVerificationGas: `0x${string}`;
                sender: `0x${string}`;
                signature: `0x${string}`;
                verificationGasLimit: `0x${string}`;
            }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "sender" | "verificationGasLimit">, entrypoint: `0x${string}`, chainId: `0x${string}`, context: unknown];
            ReturnType: import("viem").OneOf<{
                paymasterAndData: `0x${string}`;
            } | {
                paymaster: `0x${string}`;
                paymasterData: `0x${string}`;
                paymasterVerificationGasLimit: `0x${string}`;
                paymasterPostOpGasLimit: `0x${string}`;
            }>;
        }]>;
        isApexWallet?: true;
        isAvalanche?: true;
        isBackpack?: true;
        isBifrost?: true;
        isBitKeep?: true;
        isBitski?: true;
        isBlockWallet?: true;
        isBraveWallet?: true;
        isCoinbaseWallet?: true;
        isDawn?: true;
        isEnkrypt?: true;
        isExodus?: true;
        isFrame?: true;
        isFrontier?: true;
        isGamestop?: true;
        isHyperPay?: true;
        isImToken?: true;
        isKuCoinWallet?: true;
        isMathWallet?: true;
        isMetaMask?: true;
        isOkxWallet?: true;
        isOKExWallet?: true;
        isOneInchAndroidWallet?: true;
        isOneInchIOSWallet?: true;
        isOpera?: true;
        isPhantom?: true;
        isPortal?: true;
        isRabby?: true;
        isRainbow?: true;
        isStatus?: true;
        isTally?: true;
        isTokenPocket?: true;
        isTokenary?: true;
        isTrust?: true;
        isTrustWallet?: true;
        isXDEFI?: true;
        isZerion?: true;
        providers?: {
            on: <event extends keyof import("viem").EIP1193EventMap>(event: event, listener: import("viem").EIP1193EventMap[event]) => void;
            removeListener: <event_1 extends keyof import("viem").EIP1193EventMap>(event: event, listener: import("viem").EIP1193EventMap[event]) => void;
            request: import("viem").EIP1193RequestFn<[{
                Method: "web3_clientVersion";
                Parameters?: undefined;
                ReturnType: string;
            }, {
                Method: "web3_sha3";
                Parameters: [data: `0x${string}`];
                ReturnType: string;
            }, {
                Method: "net_listening";
                Parameters?: undefined;
                ReturnType: boolean;
            }, {
                Method: "net_peerCount";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "net_version";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_blobBaseFee";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_blockNumber";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_call";
                Parameters: [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>] | [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier] | [transaction: import("viem").ExactPartial<import("viem").RpcTransactionRequest>, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier, stateOverrideSet: import("viem").RpcStateOverride];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_chainId";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_coinbase";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_estimateGas";
                Parameters: [transaction: import("viem").RpcTransactionRequest] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag, stateOverride: import("viem").RpcStateOverride];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_feeHistory";
                Parameters: [blockCount: `0x${string}`, newestBlock: `0x${string}` | import("viem").BlockTag, rewardPercentiles: number[]];
                ReturnType: import("viem").RpcFeeHistory;
            }, {
                Method: "eth_gasPrice";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getBalance";
                Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getBlockByHash";
                Parameters: [hash: `0x${string}`, includeTransactionObjects: boolean];
                ReturnType: import("viem").RpcBlock;
            }, {
                Method: "eth_getBlockByNumber";
                Parameters: [block: `0x${string}` | import("viem").BlockTag, includeTransactionObjects: boolean];
                ReturnType: import("viem").RpcBlock;
            }, {
                Method: "eth_getBlockTransactionCountByHash";
                Parameters: [hash: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getBlockTransactionCountByNumber";
                Parameters: [block: `0x${string}` | import("viem").BlockTag];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getCode";
                Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getFilterChanges";
                Parameters: [filterId: `0x${string}`];
                ReturnType: `0x${string}`[] | {
                    address: `0x${string}`;
                    blockHash: `0x${string}`;
                    blockNumber: `0x${string}`;
                    data: `0x${string}`;
                    logIndex: `0x${string}`;
                    transactionHash: `0x${string}`;
                    transactionIndex: `0x${string}`;
                    removed: boolean;
                }[];
            }, {
                Method: "eth_getFilterLogs";
                Parameters: [filterId: `0x${string}`];
                ReturnType: {
                    address: `0x${string}`;
                    blockHash: `0x${string}`;
                    blockNumber: `0x${string}`;
                    data: `0x${string}`;
                    logIndex: `0x${string}`;
                    transactionHash: `0x${string}`;
                    transactionIndex: `0x${string}`;
                    removed: boolean;
                }[];
            }, {
                Method: "eth_getLogs";
                Parameters: [{
                    address?: `0x${string}` | `0x${string}`[];
                    topics?: import("viem").LogTopic[];
                } & ({
                    fromBlock?: `0x${string}` | import("viem").BlockTag;
                    toBlock?: `0x${string}` | import("viem").BlockTag;
                    blockHash?: undefined;
                } | {
                    fromBlock?: undefined;
                    toBlock?: undefined;
                    blockHash?: `0x${string}`;
                })];
                ReturnType: {
                    address: `0x${string}`;
                    blockHash: `0x${string}`;
                    blockNumber: `0x${string}`;
                    data: `0x${string}`;
                    logIndex: `0x${string}`;
                    transactionHash: `0x${string}`;
                    transactionIndex: `0x${string}`;
                    removed: boolean;
                }[];
            }, {
                Method: "eth_getProof";
                Parameters: [address: `0x${string}`, storageKeys: `0x${string}`[], block: `0x${string}` | import("viem").BlockTag];
                ReturnType: import("viem").RpcProof;
            }, {
                Method: "eth_getStorageAt";
                Parameters: [address: `0x${string}`, index: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getTransactionByBlockHashAndIndex";
                Parameters: [hash: `0x${string}`, index: `0x${string}`];
                ReturnType: import("viem").RpcTransaction;
            }, {
                Method: "eth_getTransactionByBlockNumberAndIndex";
                Parameters: [block: `0x${string}` | import("viem").BlockTag, index: `0x${string}`];
                ReturnType: import("viem").RpcTransaction;
            }, {
                Method: "eth_getTransactionByHash";
                Parameters: [hash: `0x${string}`];
                ReturnType: import("viem").RpcTransaction;
            }, {
                Method: "eth_getTransactionCount";
                Parameters: [address: `0x${string}`, block: `0x${string}` | import("viem").BlockTag | import("viem").RpcBlockIdentifier];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getTransactionReceipt";
                Parameters: [hash: `0x${string}`];
                ReturnType: import("viem").RpcTransactionReceipt;
            }, {
                Method: "eth_getUncleByBlockHashAndIndex";
                Parameters: [hash: `0x${string}`, index: `0x${string}`];
                ReturnType: import("viem").RpcUncle;
            }, {
                Method: "eth_getUncleByBlockNumberAndIndex";
                Parameters: [block: `0x${string}` | import("viem").BlockTag, index: `0x${string}`];
                ReturnType: import("viem").RpcUncle;
            }, {
                Method: "eth_getUncleCountByBlockHash";
                Parameters: [hash: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_getUncleCountByBlockNumber";
                Parameters: [block: `0x${string}` | import("viem").BlockTag];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_maxPriorityFeePerGas";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_newBlockFilter";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_newFilter";
                Parameters: [filter: {
                    fromBlock?: `0x${string}` | import("viem").BlockTag;
                    toBlock?: `0x${string}` | import("viem").BlockTag;
                    address?: `0x${string}` | `0x${string}`[];
                    topics?: import("viem").LogTopic[];
                }];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_newPendingTransactionFilter";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_protocolVersion";
                Parameters?: undefined;
                ReturnType: string;
            }, {
                Method: "eth_sendRawTransaction";
                Parameters: [signedTransaction: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_uninstallFilter";
                Parameters: [filterId: `0x${string}`];
                ReturnType: boolean;
            }, {
                Method: "eth_accounts";
                Parameters?: undefined;
                ReturnType: `0x${string}`[];
            }, {
                Method: "eth_chainId";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_estimateGas";
                Parameters: [transaction: import("viem").RpcTransactionRequest] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag] | [transaction: import("viem").RpcTransactionRequest, block: `0x${string}` | import("viem").BlockTag, stateOverride: import("viem").RpcStateOverride];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_requestAccounts";
                Parameters?: undefined;
                ReturnType: `0x${string}`[];
            }, {
                Method: "eth_sendTransaction";
                Parameters: [transaction: import("viem").RpcTransactionRequest];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_sendRawTransaction";
                Parameters: [signedTransaction: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_sign";
                Parameters: [address: `0x${string}`, data: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_signTransaction";
                Parameters: [request: import("viem").RpcTransactionRequest];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_signTypedData_v4";
                Parameters: [address: `0x${string}`, message: string];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_syncing";
                Parameters?: undefined;
                ReturnType: false | import("viem").NetworkSync;
            }, {
                Method: "personal_sign";
                Parameters: [data: `0x${string}`, address: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "wallet_addEthereumChain";
                Parameters: [chain: import("viem").AddEthereumChainParameter];
                ReturnType: null;
            }, {
                Method: "wallet_getCallsStatus";
                Parameters?: [string];
                ReturnType: import("viem").WalletGetCallsStatusReturnType<`0x${string}`, `0x${string}`>;
            }, {
                Method: "wallet_getCapabilities";
                Parameters?: [`0x${string}`];
                ReturnType: {
                    [x: `0x${string}`]: import("viem").WalletCapabilities;
                };
            }, {
                Method: "wallet_getPermissions";
                Parameters?: undefined;
                ReturnType: import("viem").WalletPermission[];
            }, {
                Method: "wallet_grantPermissions";
                Parameters?: [import("viem").WalletGrantPermissionsParameters];
                ReturnType: {
                    expiry: number;
                    factory?: `0x${string}`;
                    factoryData?: string;
                    grantedPermissions: readonly {
                        data: unknown;
                        policies: readonly {
                            data: unknown;
                            type: string;
                        }[];
                        required?: boolean;
                        type: string;
                    }[];
                    permissionsContext: string;
                    signerData?: {
                        userOpBuilder?: `0x${string}`;
                        submitToAddress?: `0x${string}`;
                    };
                };
            }, {
                Method: "wallet_requestPermissions";
                Parameters: [permissions: {
                    eth_accounts: Record<string, any>;
                }];
                ReturnType: import("viem").WalletPermission[];
            }, {
                Method: "wallet_revokePermissions";
                Parameters: [permissions: {
                    eth_accounts: Record<string, any>;
                }];
                ReturnType: null;
            }, {
                Method: "wallet_sendCalls";
                Parameters?: import("viem").WalletSendCallsParameters<import("viem").WalletCapabilities, `0x${string}`, `0x${string}`>;
                ReturnType: string;
            }, {
                Method: "wallet_showCallsStatus";
                Parameters?: [string];
                ReturnType: void;
            }, {
                Method: "wallet_switchEthereumChain";
                Parameters: [chain: {
                    chainId: string;
                }];
                ReturnType: null;
            }, {
                Method: "wallet_watchAsset";
                Parameters: import("viem").WatchAssetParams;
                ReturnType: boolean;
            }, {
                Method: "eth_chainId";
                Parameters?: undefined;
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_estimateUserOperationGas";
                Parameters: [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`] | [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`, stateOverrideSet: import("viem").RpcStateOverride];
                ReturnType: import("viem").RpcEstimateUserOperationGasReturnType;
            }, {
                Method: "eth_getUserOperationByHash";
                Parameters: [hash: `0x${string}`];
                ReturnType: import("viem").RpcGetUserOperationByHashReturnType;
            }, {
                Method: "eth_getUserOperationReceipt";
                Parameters: [hash: `0x${string}`];
                ReturnType: import("viem").RpcUserOperationReceipt;
            }, {
                Method: "eth_sendUserOperation";
                Parameters: [userOperation: import("viem").RpcUserOperation, entrypoint: `0x${string}`];
                ReturnType: `0x${string}`;
            }, {
                Method: "eth_supportedEntryPoints";
                Parameters?: undefined;
                ReturnType: readonly `0x${string}`[];
            }, {
                Method: "pm_getPaymasterStubData";
                Parameters?: [userOperation: import("viem").OneOf<import("wagmi/chains").PartialBy<Pick<{
                    callData: `0x${string}`;
                    callGasLimit: `0x${string}`;
                    initCode?: `0x${string}`;
                    maxFeePerGas: `0x${string}`;
                    maxPriorityFeePerGas: `0x${string}`;
                    nonce: `0x${string}`;
                    paymasterAndData?: `0x${string}`;
                    preVerificationGas: `0x${string}`;
                    sender: `0x${string}`;
                    signature: `0x${string}`;
                    verificationGasLimit: `0x${string}`;
                }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "preVerificationGas" | "sender" | "verificationGasLimit" | "initCode">, "maxFeePerGas" | "maxPriorityFeePerGas" | "callGasLimit" | "preVerificationGas" | "verificationGasLimit" | "initCode"> | import("wagmi/chains").PartialBy<Pick<{
                    callData: `0x${string}`;
                    callGasLimit: `0x${string}`;
                    factory?: `0x${string}`;
                    factoryData?: `0x${string}`;
                    maxFeePerGas: `0x${string}`;
                    maxPriorityFeePerGas: `0x${string}`;
                    nonce: `0x${string}`;
                    paymaster?: `0x${string}`;
                    paymasterData?: `0x${string}`;
                    paymasterPostOpGasLimit?: `0x${string}`;
                    paymasterVerificationGasLimit?: `0x${string}`;
                    preVerificationGas: `0x${string}`;
                    sender: `0x${string}`;
                    signature: `0x${string}`;
                    verificationGasLimit: `0x${string}`;
                }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "sender" | "verificationGasLimit">, "maxFeePerGas" | "maxPriorityFeePerGas" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "verificationGasLimit">>, entrypoint: `0x${string}`, chainId: `0x${string}`, context: unknown];
                ReturnType: import("viem").OneOf<{
                    paymasterAndData: `0x${string}`;
                } | {
                    paymaster: `0x${string}`;
                    paymasterData: `0x${string}`;
                    paymasterVerificationGasLimit: `0x${string}`;
                    paymasterPostOpGasLimit: `0x${string}`;
                }> & {
                    sponsor?: {
                        name: string;
                        icon?: string;
                    };
                    isFinal?: boolean;
                };
            }, {
                Method: "pm_getPaymasterData";
                Parameters?: [userOperation: Pick<{
                    callData: `0x${string}`;
                    callGasLimit: `0x${string}`;
                    initCode?: `0x${string}`;
                    maxFeePerGas: `0x${string}`;
                    maxPriorityFeePerGas: `0x${string}`;
                    nonce: `0x${string}`;
                    paymasterAndData?: `0x${string}`;
                    preVerificationGas: `0x${string}`;
                    sender: `0x${string}`;
                    signature: `0x${string}`;
                    verificationGasLimit: `0x${string}`;
                }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "preVerificationGas" | "sender" | "verificationGasLimit" | "initCode"> | Pick<{
                    callData: `0x${string}`;
                    callGasLimit: `0x${string}`;
                    factory?: `0x${string}`;
                    factoryData?: `0x${string}`;
                    maxFeePerGas: `0x${string}`;
                    maxPriorityFeePerGas: `0x${string}`;
                    nonce: `0x${string}`;
                    paymaster?: `0x${string}`;
                    paymasterData?: `0x${string}`;
                    paymasterPostOpGasLimit?: `0x${string}`;
                    paymasterVerificationGasLimit?: `0x${string}`;
                    preVerificationGas: `0x${string}`;
                    sender: `0x${string}`;
                    signature: `0x${string}`;
                    verificationGasLimit: `0x${string}`;
                }, "nonce" | "maxFeePerGas" | "maxPriorityFeePerGas" | "callData" | "callGasLimit" | "factory" | "factoryData" | "preVerificationGas" | "sender" | "verificationGasLimit">, entrypoint: `0x${string}`, chainId: `0x${string}`, context: unknown];
                ReturnType: import("viem").OneOf<{
                    paymasterAndData: `0x${string}`;
                } | {
                    paymaster: `0x${string}`;
                    paymasterData: `0x${string}`;
                    paymasterVerificationGasLimit: `0x${string}`;
                    paymasterPostOpGasLimit: `0x${string}`;
                }>;
            }]>;
            isApexWallet?: true;
            isAvalanche?: true;
            isBackpack?: true;
            isBifrost?: true;
            isBitKeep?: true;
            isBitski?: true;
            isBlockWallet?: true;
            isBraveWallet?: true;
            isCoinbaseWallet?: true;
            isDawn?: true;
            isEnkrypt?: true;
            isExodus?: true;
            isFrame?: true;
            isFrontier?: true;
            isGamestop?: true;
            isHyperPay?: true;
            isImToken?: true;
            isKuCoinWallet?: true;
            isMathWallet?: true;
            isMetaMask?: true;
            isOkxWallet?: true;
            isOKExWallet?: true;
            isOneInchAndroidWallet?: true;
            isOneInchIOSWallet?: true;
            isOpera?: true;
            isPhantom?: true;
            isPortal?: true;
            isRabby?: true;
            isRainbow?: true;
            isStatus?: true;
            isTally?: true;
            isTokenPocket?: true;
            isTokenary?: true;
            isTrust?: true;
            isTrustWallet?: true;
            isXDEFI?: true;
            isZerion?: true;
            providers?: any[];
            _events?: {
                connect?: () => void;
            };
            _state?: {
                accounts?: string[];
                initialized?: boolean;
                isConnected?: boolean;
                isPermanentlyDisconnected?: boolean;
                isUnlocked?: boolean;
            };
        }[];
        _events?: {
            connect?: () => void;
        };
        _state?: {
            accounts?: string[];
            initialized?: boolean;
            isConnected?: boolean;
            isPermanentlyDisconnected?: boolean;
            isUnlocked?: boolean;
        };
    }>;
    getClient?: (parameters?: {
        chainId?: number;
    }) => Promise<never>;
    isAuthorized: () => Promise<boolean>;
    switchChain?: (parameters: {
        addEthereumChainParameter?: import("@wagmi/core/internal").ExactPartial<import("@wagmi/core/internal").Omit<import("viem").AddEthereumChainParameter, "chainId">>;
        chainId: number;
    }) => Promise<Chain>;
    onAccountsChanged: (accounts: string[]) => void;
    onChainChanged: (chainId: string) => void;
    onConnect: ((connectInfo: import("viem").ProviderConnectInfo) => void) & ((connectInfo: import("viem").ProviderConnectInfo) => void);
    onDisconnect: (error?: Error) => void;
    onMessage?: (message: import("viem").ProviderMessage) => void;
}, Record<string, unknown>>;
export {};
